@@ -6,7 +6,7 @@ from httpx import Response
 INVENTORY_BASE_URL = "http://example.com/"
 inventory_mock = respx.mock(base_url=INVENTORY_BASE_URL, assert_all_called=False)
 inventory_mock.get(
-    path__regex=r"/private/v1/inventory/(?P<warehouse_code>\w+)/$",
+    path__regex=r"/private/api/v1/inventory/(?P<warehouse_code>\w+)/$",
     name="inventory_stock",
 ).mock(
     return_value=Response(
@@ -21,6 +21,6 @@ for name, action in (
     ("inventory_release_create", "release"),
 ):
     inventory_mock.post(
-        path__regex=fr"/private/v1/inventory/(?P<warehouse_code>\w+)/{action}/$",
+        path__regex=fr"/private/api/v1/inventory/(?P<warehouse_code>\w+)/{action}/$",
         name=name,
     ).mock(return_value=Response(HTTPStatus.NO_CONTENT))
